==> flutter_conscent_plugin-0.3.6.tar.gz: lib/passes_webviews.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppsss(),
    ),
  );
}

class WebViewAppsss extends StatefulWidget {
  const WebViewAppsss({super.key});

  @override
  State<WebViewAppsss> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewAppsss> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  // dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${ApiMode.BASE_URL}api/v1/login-challenge/$loginId');

    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();

      String sessionId = loginChallengeget.sessionId.toString();
      prefs.setString('sessionId', sessionId);
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${ApiMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {

    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {

          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();

            String sessionId = await getSessionID(loginId!);
            submitDatas(ConscentInitializer.mClientId.toString(),
                ConscentInitializer.mContentId.toString(), sessionId);
          }
        });
  }

  // ... to here.

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;


    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  //'https://conscent.netlify.app/overlay?clientId=5f92a62013332e0f667794dc&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                  '${ApiMode.SERVICE_BASE_URL}/overlay?purchaseMode=PASS&loginChallenge=$loginId&clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}',
              javascriptMode: JavascriptMode.unrestricted,
            userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {

                <JavascriptChannel>{_javascriptChannel()};
              },
              onWebViewCreated: (controller) {

              },
              navigationDelegate: (NavigationRequest request) {


                if (request.url.startsWith('https://xyz.zyz')) {


                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){

                  Navigator.pop(context);

                  //  navigator?.pop();
                  //  Navigator.pop(context, true);
                  //Navigator.popAndPushNamed(context, '/Subscribe');
                  // Navigator.of(context).popUntil((route) => route.isFirst);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.3.8.tar.gz: lib/passes_webviews.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';
import 'constants.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppsss(),
    ),
  );
}

class WebViewAppsss extends StatefulWidget {
  const WebViewAppsss({super.key});

  @override
  State<WebViewAppsss> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewAppsss> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  // dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');

    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();

      String sessionId = loginChallengeget.sessionId.toString();
      prefs.setString('sessionId', sessionId);
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });

    if (response.statusCode == 201) {
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {

    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {

          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();

            String sessionId = await getSessionID(loginId!);
            submitDatas(ConscentInitializer.mClientId.toString(),
                ConscentInitializer.mContentId.toString(), sessionId);
          }
        });
  }

  // ... to here.

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;


    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  //'https://conscent.netlify.app/overlay?clientId=5f92a62013332e0f667794dc&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                  '${APIMode.SERVICE_BASE_URL}/overlay?purchaseMode=PASS&loginChallenge=$loginId&clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}',
              javascriptMode: JavascriptMode.unrestricted,
            userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {

                <JavascriptChannel>{_javascriptChannel()};
              },
              onWebViewCreated: (controller) {

              },
              navigationDelegate: (NavigationRequest request) {


                if (request.url.startsWith('https://xyz.zyz')) {


                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){

                  Navigator.pop(context);

                  //  navigator?.pop();
                  //  Navigator.pop(context, true);
                  //Navigator.popAndPushNamed(context, '/Subscribe');
                  // Navigator.of(context).popUntil((route) => route.isFirst);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
